@@ -1,7 +1,45 @@
 '''datapkg is a tool for distributing, discovering and installing knowledge and
 data 'packages'.
 
-datapkg has two main distinct uses:
+Contents:
+    1. Quickstart
+    2. Tutorial
+
+1. Quickstart
++++++++++++++
+
+Create a new data package on disk using standard file layout:
+
+    $ datapkg create MyNewDataPackage
+
+Edit the metadata:
+
+    $ vim MyNewDataPackage/setup.py
+
+Add some data:
+
+    $ cp mydata.csv MyNewDataPackage
+    $ cp mydata.js MyNewDataPackage
+    $ etc ...
+
+Register in your local repository on on CKAN:
+
+    $ datapkg repo init # if repo not already initialized
+    $ datapkg register MyNewDataPackage
+    $ # OR
+    $ datapkg register --repository=http://ckan.net/api/rest/ --api-key=....  MyNewDataPackage
+
+Check it has registered ok:
+
+    $ datapkg info MyNewDataPackage
+    $ # OR
+    $ datapkg info --repository=http://ckan.net/api/rest/ MyNewDataPackage
+
+
+2. Tutorial
++++++++++++
+
+datapkg has two distinct uses:
 
     1. Finding, obtaining and accessing material made available *by* others.
     2. Assisting you to make material available *to* others.
@@ -111,13 +149,11 @@ To access the package from python code do:
 
 Search for a package on CKAN::
 
-    $ datapkg ckanlist
-    $ datapkg ckantags # list tags
-    $ datapkg ckansearch [NOT YET OPERATIONAL]
+    $ datapkg --repository=http://ckan.net/api/rest/ list
 
 You can find out about a package on CKAN by doing::
 
-    $ datapkg ckanshow ${name}
+    $ datapkg --repository=http://ckan.net/api/rest/ info {pkg-name}
 
 [NOT YET OPERATIONAL]
 
@@ -139,6 +175,8 @@ be 3 files/directories:
 
   1. MANIFEST.in: this specifies what files/directories within the distribution
   directory should actually be included in the package.
+    * For instructions on using the MANIFEST.in to specify what files to
+      include see <http://docs.python.org/distutils/commandref.html#sdist-cmd>
   2. *.egg-info: this directory you can safely ignore (though don't delete it)
   3. setup.py: this files holds metadata about your package.
 
@@ -173,11 +211,7 @@ repository:
 
 Once that is done you register the package on CKAN by doing::
 
-    $ datapkg ckanregister {path} # on CKAN
-
-You can update an existing package on CKAN by doing::
-
-    $ datapkg ckanupdate ${path}
+    $ datapkg --repository=http://ckan.net/api/rest/ register {path}
 
 
 3. For Developers
@@ -186,7 +220,7 @@ You can update an existing package on CKAN by doing::
 The easiest thing (which also guarantees up-to-date-ness) is to look through
 the unit tests in ./datapkg/tests/
 '''
-__version__ = '0.1'
+__version__ = '0.2'
 __description__ = 'Data packaging system and utilities.'
 __description_long__ = __doc__
 __license__ = 'MIT'
@@ -216,122 +250,19 @@ SOFTWARE.
 
 import os
 
-# Todo: Tests on these ckan- functions.
-
-def ckanlist(base_location=None):
-    ckan = start_ckanclient(base_location)
-    ckan.package_register_get()
-    print_status(ckan)
-    if ckan.last_status == 200:
-        if ckan.last_message != None:
-            print "\n".join(ckan.last_message)
-        else:
-            print "No response data. Check the resource location."
-
-def ckantags(base_location=None):
-    ckan = start_ckanclient(base_location)
-    ckan.tag_register_get()
-    print_status(ckan)
-    if ckan.last_status == 200:
-        if ckan.last_message != None:
-            print "\n".join(ckan.last_message)
-        else:
-            print "No response data. Check the resource location."
-
-def ckanshow(pkg_name, base_location=None):
-    ckan = start_ckanclient(base_location)
-    ckan.package_entity_get(pkg_name)
-    print_status(ckan)
-    if ckan.last_status == 200:
-        if ckan.last_message != None:
-            package_dict = ckan.last_message
-            for (name, value) in package_dict.items():
-                if name == 'tags':
-                    value = " ".join(value)
-                print "%s: %s" % (name, value)
-
-def ckanregister(path, base_location=None, api_key=None):
-    pkg_dict = load_pkg_metadata(path)
-    ckan = start_ckanclient(base_location, api_key)
-    ckan.package_register_post(pkg_dict)
-    print_status(ckan)
-
-def ckanupdate(path, base_location=None, api_key=None):
-    pkg_dict = load_pkg_metadata(path)
-    ckan = start_ckanclient(base_location, api_key)
-    ckan.package_entity_put(pkg_dict)
-    print_status(ckan)
-
-def load_pkg_metadata(path):
-    from datapkg.pypkgtools import PyPkgTools
-    tool = PyPkgTools()
-    #print "datapkg: Loading metadata from: %s" % path
-    data = tool.load_metadata(path)
-    name = data.get_name()
-    if name == 'UNKNOWN': name = ''
-    title = data.get_description()
-    if title == 'UNKNOWN': title = ''
-    url = data.get_url()
-    if url == 'UNKNOWN': url = ''
-    notes = data.get_long_description()
-    if notes == 'UNKNOWN': notes = ''
-    download_url = data.get_download_url()
-    if download_url == 'UNKNOWN': download_url = ''
-    tags = " ".join(data.get_keywords()).split(' ')
-    pkg_metadata = {
-        'name': name,
-        'title': title,
-        'url': url,
-        'download_url': download_url,
-        'notes': notes,
-        'tags': tags,
-    }
-    #print "datapkg: Loaded package metadata: %s" % pkg_metadata
-    return pkg_metadata
-
-def start_ckanclient(base_location=None, api_key=None):
-    from ckanclient import CkanClient
-    service_kwds = {}
-    if base_location:
-        service_kwds['base_location'] = base_location
-    if api_key:
-        service_kwds['api_key'] = api_key
-    #print "datapkg: CKAN config: %s" % service_kwds 
-    return CkanClient(**service_kwds)
-
-def print_status(ckan):
-    if ckan.last_status == None:
-        if ckan.last_url_error:
-            print "Network error: %s" % ckan.last_url_error.reason[1]
-    elif ckan.last_status == 200:
-        pass #print "Datapkg operation was a success."
-    elif ckan.last_status == 400:
-        print "Bad request (400). Please check the submission."
-    elif ckan.last_status == 403:
-        print "Operation not authorised (403). Check the API key."
-    elif ckan.last_status == 404:
-        print "Resource not found (404). Please check names and locations."
-    elif ckan.last_status == 409:
-        print "Package already registered (409). Update with 'ckanupdate'?"
-    elif ckan.last_status == 500:
-        print "Server error (500). Unable to service request. Seek help"
-    else:
-        print "System error (%s). Seek help." %  ckan.last_status
-
-from paste.script.templates import Template
-class DataPkgTemplate(Template):
-    _template_dir = 'templates/default_distribution'
-    summary = 'DataPkg default distribution template'
-
-def install(name):
-    from manager import PackageManager
-    mgr = PackageManager()
-    mgr.install(name)
-
-def upload(path='.'):
-    fns = os.listdir('.')
-    if 'setup.py' not in fns:
-        msg = '%s does not look like a data package (no setup.py ...)' % path
-        raise Exception(msg)
-    # TODO: implement the rest of this
+# TODO: 2009-03-09 Remove this.
+# def install(name):
+#     from manager import PackageManager
+#     mgr = PackageManager()
+#     mgr.install(name)
+# 
+# def upload(path='.'):
+#     fns = os.listdir('.')
+#     if 'setup.py' not in fns:
+#         msg = '%s does not look like a data package (no setup.py ...)' % path
+#         raise Exception(msg)
+#     # TODO: implement the rest of this
     
+
+class DatapkgException(Exception):
+    pass
